@@ -1,4 +1,5 @@
 # Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2009 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -39,14 +40,14 @@ use base 'EBox::Model::DataTable';
 use constant MAC_FETCH_TRIES => 3;
 
 
-sub new 
+sub new
 {
 	my $class = shift;
 	my %parms = @_;
-	
+
 	my $self = $class->SUPER::new(@_);
 	bless($self, $class);
-	
+
 	return $self;
 }
 
@@ -54,7 +55,7 @@ sub weights
 {
 	my @options;
 	for my $weight (1..15) {
-		push @options, { 'value' => $weight, 
+		push @options, { 'value' => $weight,
 				 'printableValue' => $weight};
 	}
 	return \@options;
@@ -63,10 +64,10 @@ sub weights
 sub interfaces
 {
 	my $network = EBox::Global->modInstance('network');
-	my @ifaces = (@{$network->InternalIfaces()}, 
+	my @ifaces = (@{$network->InternalIfaces()},
 		      @{$network->ExternalIfaces()});
-	      
-	my @options = map { 'value' => $_, 
+
+	my @options = map { 'value' => $_,
 			     'printableValue' => $_ }, @ifaces;
 
 	return \@options;
@@ -74,8 +75,8 @@ sub interfaces
 
 sub _table
 {
-	my @tableHead = 
-	 ( 
+	my @tableHead =
+	 (
 
 		new EBox::Types::Text(
 					'fieldName' => 'name',
@@ -86,7 +87,7 @@ sub _table
 				      ),
 		new EBox::Types::Text(
 					'fieldName' => 'ip',
-					'printableName' => __('IP Address'),
+					'printableName' => __('IP address'),
 					'size' => '16',
 					'unique' => 1,
 					'editable' => 1
@@ -105,7 +106,7 @@ sub _table
 					'editable' => 1,
 					'trailingText' => 'Kb/s',
 					'help' => __('Upload rate in Kbits/s for this gateway.')
-								
+
 				),
 		new EBox::Types::Int(
 					'fieldName' => 'download',
@@ -121,7 +122,7 @@ sub _table
 					'size' => '2',
 					'populate' => \&weights,
 					'editable' => 1,
-					'help' => __('This field is only useful if you have ' . 
+					'help' => __('This field is only useful if you have ' .
 								 'more than one router and  the balance ' .
 								 'traffic feature is enabled.')
 				),
@@ -134,16 +135,18 @@ sub _table
 
 	 );
 
-	my $dataTable = 
-		{ 
+	my $dataTable =
+		{
 			'tableName' => 'GatewayTable',
-			'printableTableName' => __('Gateway list'),
+			'printableTableName' => __('Gateways List'),
 			'pageTitle'	=> __('Gateways'),
 			'automaticRemove' => 1,
+            'enableProperty' => 1,
+            'defaultEnabledValue' => 1,
 			'defaultController' =>
 				'/ebox/Network/Controller/GatewayTable',
 			'defaultActions' =>
-				[	
+				[
 				'add', 'del',
 				'move',  'editField',
 				'changeView'
@@ -166,9 +169,7 @@ sub _table
 #
 sub validateRow()
 {
-	my $self = shift;
-	my $action = shift;
-	my %params = @_;
+	my ($self, $action, %params) = @_;
 
 	my $network = EBox::Global->modInstance('network');
 	checkIP($params{'ip'}, __("ip address"));
@@ -186,13 +187,46 @@ sub validateRow()
 	}
 }
 
+# Method: addedRowNotify
+#
+# Overrides:
+#
+#      <EBox::Model::DataTable::addedRowNotify>
+#
+sub addedRowNotify
+{
+    my ($self, $row) = @_;
+
+    if ($row->valueByName('default')) {
+        my $network = $self->parentModule();
+        $network->storeSelectedDefaultGateway($row->id());
+    }
+}
+
+# Method: updatedRowNotify
+#
+# Overrides:
+#
+#     <EBox::Model::DataTable::updatedRowNotify>
+#
+sub updatedRowNotify
+{
+    my ($self, $newRow, $force) = @_;
+
+    if ($newRow->valueByName('default')) {
+        my $network = $self->parentModule();
+        $network->storeSelectedDefaultGateway($newRow->id());
+    }
+}
+
+# Returns default gateway
 sub defaultGateway()
 {
 	my $self = shift;
 
-	my $default = $self->find('default' => 1);
-	if ($default) {
-		return $default->valueByName('ip');
+	my $row = $self->find('default' => 1);
+	if ($row) {
+		return $row->valueByName('ip');
 	} else {
 		return undef;
 	}
@@ -203,8 +237,8 @@ sub iproute2TableIds()
 	my $self = shift;
 
 	my @ids;
-	for my $row (@{$self->rows()}) {
-		push (@ids, $row->id());
+	for my $id (@{$self->ids()}) {
+		push (@ids, $id);
 	}
 
 	return \@ids;
@@ -222,17 +256,34 @@ sub marksForRouters()
 		$marks->{$id} = $i;
 		$i++;
 	}
-	
+
 	return $marks;
 }
 
-sub gateways()
+# Returns only enabled gateways
+sub gateways
 {
-	my $self = shift;
+    my ($self) = @_;
+
+    $self->_gateways(0);
+}
+
+# Returns all gateways
+sub allGateways
+{
+	my ($self) = @_;
+
+    $self->_gateways(1);
+}
+
+sub _gateways # (all)
+{
+    my ($self, $all) = @_;
 
 	my @gateways;
 
-	foreach my $gw (@{$self->rows()}) {
+	foreach my $id (@{$all ? $self->ids() : $self->enabledRows()}) {
+		my $gw = $self->row($id);
 		push (@gateways, {
 							id => $gw->id(),
 							name => $gw->valueByName('name'),
@@ -252,7 +303,7 @@ sub gatewaysWithMac
 {
 	my ($self) = @_;
 
-	my @gateways = @{$self->gateways()};
+	my @gateways = @{$self->allGateways()};
 	foreach my $gw (@gateways) {
 		$gw->{'mac'} = _getRouterMac($gw->{'ip'});
 	}
@@ -269,7 +320,7 @@ sub _getRouterMac
 	for (0..MAC_FETCH_TRIES) {
 		system("ping -c 1 -W 3 $ip  > /dev/null 2> /dev/null");
 		$mac = Net::ARP::arp_lookup($macif, $ip);
-		return $mac if ($mac ne '00:00:00:00:00:00'); 
+		return $mac if ($mac ne '00:00:00:00:00:00');
 	}
 	return $mac;
 }
